MCPcopy Create free account
hub / github.com/ComputationalRobotics/XM-code / GradLambdaKernal

Function GradLambdaKernal

XM/include/XM/trustregion.h:35–40  ·  view source on GitHub ↗

Source from the content-addressed store, hash-verified

33
34template <typename T>
35__global__ void GradLambdaKernal(T* news, T* olds, size_s n){
36 size_s i = blockIdx.x * blockDim.x + threadIdx.x;
37 if(i<n){
38 news[i] = (olds[i+1] * olds[i+1] - 1)*olds[i+1];
39 }
40}
41
42template <typename T>
43__global__ void HessLambdaKernal(T* news, T* olds, T* oldsu, size_s n){

Callers

nothing calls this directly

Calls

no outgoing calls

Tested by

no test coverage detected